@@ -538,7 +538,7 @@ class Table(metaclass=MetaTable):
             db = cls.get_db()
             cursor = db.cursor()
             cursor.execute(*debug(f"""INSERT INTO {cls}
-                                    SET ({insert.fields()})
+                                    ({insert.fields()})
                                     VALUES ({insert.fields('%s')})
                                     RETURNING {cls.select()}""",
                                 insert.values()))
